@@ -18,7 +18,7 @@
 */
 
 #include "ktimezonecombobox.h"
-#include "helper_p.h"
+
 #include <KCalCore/ICalTimeZones>
 
 #include <KLocalizedString>
@@ -33,8 +33,10 @@ class Q_DECL_HIDDEN KTimeZoneComboBox::Private
 {
 public:
     Private(KTimeZoneComboBox *parent)
-        : mParent(parent), mAdditionalZones(0)
-    {}
+        : mParent(parent)
+        , mAdditionalZones(0)
+    {
+    }
 
     void fillComboBox();
     KTimeZoneComboBox *const mParent;
@@ -49,14 +51,16 @@ void KTimeZoneComboBox::Private::fillComboBox()
 
     // Read all system time zones
     const QList<QByteArray> lstTimeZoneIds = QTimeZone::availableTimeZoneIds();
+    mZones.reserve(lstTimeZoneIds.count());
     for (const QByteArray &id : lstTimeZoneIds) {
         mZones.push_back(QString::fromLatin1(id));
     }
     mZones.sort();
 
     // Prepend the list of additional timezones
-    for (const QByteArray &id : qAsConst(mAdditionalZones))
+    for (const QByteArray &id : qAsConst(mAdditionalZones)) {
         mZones.prepend(QString::fromLatin1(id));
+    }
 
     // Prepend Local, UTC and Floating, for convenience
     mZones.prepend(QStringLiteral("UTC"));        // do not use i18n here  index=2
@@ -70,7 +74,8 @@ void KTimeZoneComboBox::Private::fillComboBox()
 }
 
 KTimeZoneComboBox::KTimeZoneComboBox(QWidget *parent)
-    : KComboBox(parent), d(new KTimeZoneComboBox::Private(this))
+    : KComboBox(parent)
+    , d(new KTimeZoneComboBox::Private(this))
 {
     d->fillComboBox();
 }
